@@ -1,4 +1,3 @@
-#! /usr/local/bin/perl 
 #!/usr/bin/perl 
 
 =head1 NAME
@@ -250,7 +249,12 @@ foreach $cui1 (@c1)
 	else {
 	    print "\nThe shortest path between $cui1 and $cui2:\n";
 	}
-	print "  => @shortestpath\n\n";
+	print "  => ";
+	foreach my $concept (@shortestpath) {
+	    my ($t) = $umls->getTermList($concept); 
+	    print "$concept ($t) ";
+	}
+	print "\n";
 
 	$printFlag = 1;
     }
@@ -318,7 +322,7 @@ sub showHelp() {
 #  function to output the version number
 ##############################################################################
 sub showVersion {
-    print '$Id: findShortestPath.pl,v 1.6 2009/01/13 22:20:18 btmcinnes Exp $';
+    print '$Id: findShortestPath.pl,v 1.7 2009/01/24 15:16:34 btmcinnes Exp $';
     print "\nCopyright (c) 2008, Ted Pedersen & Bridget McInnes\n";
 }
 
