@@ -1,4 +1,3 @@
-#! /usr/local/bin/perl 
 #!/usr/bin/perl 
 
 =head1 NAME
@@ -225,8 +224,8 @@ sub minimalUsageNotes {
 sub showHelp() {
 
         
-    print "This is a utility that takes as input a cui\n";
-    print "and returns all of its possible relation given";
+    print "This is a utility that takes as input a CUI\n";
+    print "and returns all of its possible relation given\n";
     print "a specified set of sources\n\n";
   
     print "Usage: getRelation.pl [OPTIONS] CUI\n\n";
@@ -254,7 +253,7 @@ sub showHelp() {
 #  function to output the version number
 ##############################################################################
 sub showVersion {
-    print '$Id: getRelated.pl,v 1.2 2009/01/12 19:58:45 btmcinnes Exp $';
+    print '$Id: getRelated.pl,v 1.4 2009/01/25 00:19:40 btmcinnes Exp $';
     print "\nCopyright (c) 2008, Ted Pedersen & Bridget McInnes\n";
 }
 
